from setuptools import setup,find_packages
setup(
     name="mywork_krishna",
     version="0.0.1",
     author ="aksay",
     author_email ="akshyakrishna2007@gmail.com",
     packages=find_packages(),
)